@@ -1,31 +1,28 @@
 package Linux::FD::Signal;
-{
-  $Linux::FD::Signal::VERSION = '0.009';
-}
-
+$Linux::FD::Signal::VERSION = '0.010';
 use 5.006;
 
 use strict;
-use warnings FATAL => 'all';
+use warnings;
 use Linux::FD ();
 
-use parent 'IO::Handle';
-
 1;    # End of Linux::FD::Signal
 
 #ABSTRACT: Signal filehandles for Linux
 
-
 __END__
+
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Linux::FD::Signal - Signal filehandles for Linux
 
 =head1 VERSION
 
-version 0.009
+version 0.010
 
 =head1 SYNOPSIS
 
@@ -71,4 +68,3 @@ This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
